Structs
Enums
enum CalcType is a type containing operations used in the calculator.
Functions
eval takes a &str and a &mut VecDeque<f64>, evaluates the expression,
and prints the result, pushing the results onto the stack of type
VecDeque
safe_eval takes a &str evaluates the expression, returning the
resulting stack as a Result if the expression is valid, or an Err if the
expression is invalid or otherwise cannot be evaluated.
str_to_calc_type converts a string to an optional CalcType.