Enums
enum CalcType is a type containing operations used in the calculator.
Functions
eval takes a &str and a &mut VecDeque<f64>, evaluates the expression,
and prints the result, pushing the results onto the stack.
str_to_calc_type converts a string to an optional CalcType.